@@ -3,8 +3,7 @@ knitr::opts_chunk$set(
   collapse = TRUE, 
   comment = "#>",
   fig.width = 7.15,
-  fig.height = 3.5,
-  dev = 'svg')
+  fig.height = 3.5)
 
 library(qicharts2)
 
